@@ -587,7 +587,7 @@ class Git:
                     _("Branch {branch} not found in repository {rpath}").format(
                         branch=branch, rpath=rpath))
             raise GitError(
-                _("Failed to change branch to {branch} in the {rpath} "
+                _("Failed to move to branch {branch} in the {rpath} "
                   "repository").format(branch=branch,
                                                rpath=rpath), error)
         return True
